ServiceUnavailableException class

A custom exception representing a "Service Unavailable" error (HTTP 503).

This exception extends HttpServerErrorException and is thrown to indicate that the server is currently unable to handle the request. It includes a human-readable message and has an HTTP status code of HttpStatus.serviceUnavailable.

Inheritance

Constructors

ServiceUnavailableException(String message)
Creates a ServiceUnavailableException with the specified message.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
message → String
A human-readable description of the exception.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
statusCode → int
The HTTP status code associated with the exception.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited